@@ -32,6 +32,7 @@
 #include "ZenLib/Translation.h"
 #include "ZenLib/InfoMap.h"
 using namespace ZenLib;
+using std::string;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -75,6 +76,8 @@ public :
     MediaInfo_Config_MediaInfo();
     ~MediaInfo_Config_MediaInfo();
 
+    bool          RequestTerminate;
+
     //General
     Ztring Option (const String &Option, const String &Value=Ztring());
 
@@ -185,6 +188,8 @@ public :
 
     void          File_ForceParser_Set (const Ztring &NewValue);
     Ztring        File_ForceParser_Get ();
+    void          File_ForceParser_Config_Set (const Ztring &NewValue);
+    Ztring        File_ForceParser_Config_Get ();
 
     void          File_Buffer_Size_Hint_Pointer_Set (size_t* NewValue);
     size_t*       File_Buffer_Size_Hint_Pointer_Get ();
@@ -452,6 +457,7 @@ private :
     Ztring                  File_Partial_Begin;
     Ztring                  File_Partial_End;
     Ztring                  File_ForceParser;
+    Ztring                  File_ForceParser_Config;
     size_t*                 File_Buffer_Size_Hint_Pointer;
     size_t                  File_Buffer_Read_Size;
 
