@@ -87,6 +87,16 @@ Ztring Xml_Name_Escape_0_7_78 (const Ztring &Name)
 extern MediaInfo_Config Config;
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+void MediaInfo_Internal::ConvertRetour(Ztring& Retour)
+{
+    Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
+    Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
+    Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
+    Retour.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
+    Retour.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
+    Retour.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
+}
 //---------------------------------------------------------------------------
 Ztring MediaInfo_Internal::Inform()
 {
@@ -119,6 +129,16 @@ Ztring MediaInfo_Internal::Inform()
             return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_8, Export_EbuCore::AcquisitionDataOutputMode_parameterSegment);
         if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_segmentParameter") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_sp"))
             return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_8, Export_EbuCore::AcquisitionDataOutputMode_segmentParameter);
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.5_JSON"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_5, Export_EbuCore::AcquisitionDataOutputMode_Default, Export_EbuCore::Format_JSON);
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.6_JSON"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_6, Export_EbuCore::AcquisitionDataOutputMode_Default, Export_EbuCore::Format_JSON);
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_JSON"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_8, (Export_EbuCore::acquisitiondataoutputmode)MediaInfoLib::Config.AcquisitionDataOutputMode_Get(), Export_EbuCore::Format_JSON);
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_parameterSegment_JSON") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_ps_JSON"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_8, Export_EbuCore::AcquisitionDataOutputMode_parameterSegment, Export_EbuCore::Format_JSON);
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_segmentParameter_JSON") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.8_sp_JSON"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_8, Export_EbuCore::AcquisitionDataOutputMode_segmentParameter, Export_EbuCore::Format_JSON);
         if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore"))
             return Export_EbuCore().Transform(*this);
     #endif //defined(MEDIAINFO_EBUCORE_YES)
@@ -154,7 +174,7 @@ Ztring MediaInfo_Internal::Inform()
      && MediaInfoLib::Config.Inform_Get(__T("Video")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Audio")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Text")).empty()
-     && MediaInfoLib::Config.Inform_Get(__T("Chapters")).empty()
+     && MediaInfoLib::Config.Inform_Get(__T("Other")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Image")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Menu")).empty()
      ))
@@ -195,15 +215,15 @@ Ztring MediaInfo_Internal::Inform()
         if (Count_Get(Stream_Text))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Text_End"));
         if (Count_Get(Stream_Other))
-            Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_Begin"));
+            Retour+=MediaInfoLib::Config.Inform_Get(__T("Other_Begin"));
         for (size_t I1=0; I1<Count_Get(Stream_Other); I1++)
         {
             Retour+=Inform(Stream_Other, I1, false);
             if (I1!=Count_Get(Stream_Other)-1)
-                Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_Middle"));
+                Retour+=MediaInfoLib::Config.Inform_Get(__T("Other_Middle"));
         }
         if (Count_Get(Stream_Other))
-            Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_End"));
+            Retour+=MediaInfoLib::Config.Inform_Get(__T("Other_End"));
         if (Count_Get(Stream_Image))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Image_Begin"));
         for (size_t I1=0; I1<Count_Get(Stream_Image); I1++)
@@ -226,12 +246,7 @@ Ztring MediaInfo_Internal::Inform()
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Menu_End"));
         Retour+=MediaInfoLib::Config.Inform_Get(__T("File_End"));
 
-        Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
+        ConvertRetour(Retour);
 
         //Special characters
         Retour.FindAndReplace(__T("|SC1|"), __T("\\"), 0, Ztring_Recursive);
@@ -262,11 +277,11 @@ Ztring MediaInfo_Internal::Inform()
         HTML=true;
     #endif //defined(MEDIAINFO_HTML_YES)
     #if defined(MEDIAINFO_XML_YES)
-    if (MediaInfoLib::Config.Inform_Get()==__T("XML"))
+    if (MediaInfoLib::Config.Inform_Get()==__T("OLDXML"))
         XML=true;
     if (MediaInfoLib::Config.Inform_Get()==__T("MAXML"))
         XML_0_7_78_MA=true;
-    if (MediaInfoLib::Config.Inform_Get()==__T("MIXML"))
+    if (MediaInfoLib::Config.Inform_Get()==__T("MIXML") || MediaInfoLib::Config.Inform_Get()==__T("XML"))
         XML_0_7_78_MI=true;
     #endif //defined(MEDIAINFO_XML_YES)
     #if defined(MEDIAINFO_CSV_YES)
@@ -286,7 +301,7 @@ Ztring MediaInfo_Internal::Inform()
         Retour+= __T(">\n");
     }
     if (XML_0_7_78_MA)
-        Retour+=__T("<MediaInfo xmlns=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediainfo\" version=\"2.0beta1\">\n");
+        Retour+=__T("<MediaInfo xmlns=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediainfo\" version=\"2.0\">\n");
     if (XML)
         Retour+=__T("<File>\n");
     #endif //defined(MEDIAINFO_XML_YES)
@@ -334,12 +349,7 @@ Ztring MediaInfo_Internal::Inform()
     if (HTML) Retour+=__T("\n</body>\n</html>\n");
     if (XML_0_7_78_MA)  Retour+=__T("</MediaInfo>\n");
 
-    Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
+    ConvertRetour(Retour);
 
     //Special characters
     Retour.FindAndReplace(__T("|SC1|"), __T("\\"), 0, Ztring_Recursive);
@@ -394,7 +404,7 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
      && MediaInfoLib::Config.Inform_Get(__T("Video")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Audio")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Text")).empty()
-     && MediaInfoLib::Config.Inform_Get(__T("Chapters")).empty()
+     && MediaInfoLib::Config.Inform_Get(__T("Other")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Image")).empty()
      && MediaInfoLib::Config.Inform_Get(__T("Menu")).empty())
     {
@@ -403,8 +413,8 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
         bool HTML=MediaInfoLib::Config.Inform_Get()==__T("HTML")?true:false;
         #endif //defined(MEDIAINFO_HTML_YES)
         #if defined(MEDIAINFO_XML_YES)
-        bool XML=MediaInfoLib::Config.Inform_Get()==__T("XML")?true:false;
-        bool XML_0_7_78=(MediaInfoLib::Config.Inform_Get()==__T("MAXML") || MediaInfoLib::Config.Inform_Get()==__T("MIXML"))?true:false;
+        bool XML=MediaInfoLib::Config.Inform_Get()==__T("OLDXML")?true:false;
+        bool XML_0_7_78=(MediaInfoLib::Config.Inform_Get()==__T("MAXML") || MediaInfoLib::Config.Inform_Get()==__T("MIXML") || MediaInfoLib::Config.Inform_Get() == __T("XML"))?true:false;
         if (XML_0_7_78)
             XML=true;
         #endif //defined(MEDIAINFO_XML_YES)
@@ -437,13 +447,16 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
             #if defined(MEDIAINFO_XML_YES)
             if (XML_0_7_78)
             {
+                Ztring Options=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Options);
                 if (Champ_Pos>=Stream[StreamKind][StreamPos].size())
-                    Shouldshow=true;
+                {
+                    if (InfoOption_ShowInXml>=Options.size() || Options[InfoOption_ShowInXml]==__T('Y'))
+                        Shouldshow=true;
+                }
                 else
                 {
-                Ztring Options=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Options);
-                if (InfoOption_ShowInXml<Options.size() && Options[InfoOption_ShowInXml]==__T('Y'))
-                    Shouldshow=true;
+                    if (InfoOption_ShowInXml<Options.size() && Options[InfoOption_ShowInXml]==__T('Y'))
+                        Shouldshow=true;
                 }
             }
             else
@@ -601,12 +614,8 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
             Retour+=__T("</extra>\n");
         }
 
-        Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
-        Retour.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
+        ConvertRetour(Retour);
+
         Retour.FindAndReplace(__T("|SC1|"), __T("\\"), 0, Ztring_Recursive);
         return Retour;
     }
@@ -727,12 +736,7 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
     }
 
     //Retour=__T("<table width=\"100%\" border=\"0\" cellpadding=\"1\" cellspacing=\"2\" style=\"border:1px solid Navy\">\n<tr>\n    <td width=\"150\">Video #0</td>\n  </tr>\r\n  <tr>\n    <td><i>Codec :</i></td>\n    <td colspan=\"3\">WMV1</td>\n  </tr>\r\n  <tr>\n    <td><i>Codec/Info :</i></td>\n    <td colspan=\"3\">Windows Media Video 7</td>\n  </tr>\r\n  <tr>\n    <td><i>Width :</i></td>\n    <td colspan=\"3\">200 pixels</td>\n  </tr>\r\n  <tr>\n    <td><i>Height :</i></td>\n    <td colspan=\"3\">150 pixels</td>\n  </tr>\r\n  <tr>\n    <td><i>Aspect ratio :</i></td>\n    <td colspan=\"3\">4/3</td>\n  </tr>\r\n  <tr>\n    <td><i>Resolution :</i></td>\n    <td colspan=\"3\">24 bits</td>\n  </tr>\r\n</table>\n");
-    Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
-    Retour.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
+    ConvertRetour(Retour);
 
     //Special characters
     if (IsDirect)
